// Stored in:
// C:\Users\LAPtop\Desktop\przekaznik.ino
// ****************************************************************
// ----------------< Configuration >---------------
// Pins Arduino MEGA and compatible
// Tipo de placa:     Arduino with Ethernet Shield (W5100)
// Tipo de nodo:      Gateway
// Tipo de interfaz:  No selection (Default)
// Direccion IP nodo: 192,168,1,17
// Slot 0: ON/OFF Digital Output with Timer Option
// Slot 1: ON/OFF Digital Output with Timer Option
// Slot 2: ON/OFF Digital Output with Timer Option
// Slot 3: ON/OFF Digital Output with Timer Option
// Slot 4: ON/OFF Digital Output with Timer Option
// Slot 5: ON/OFF Digital Output with Timer Option
// Slot 6: ON/OFF Digital Output with Timer Option
// Slot 7: ON/OFF Digital Output with Timer Option
//
// Created with: NodoSouliss (version 0.7.2)    09.05.2017 23:13:10
// ****************************************************************

// Let the IDE point to the Souliss framework
#include "SoulissFramework.h"

// Configure the framework
#include "bconf/StandardArduino.h"          // Use a standard Arduino
#include "conf/ethW5100.h"                  // Ethernet through Wiznet W5100
#include "conf/Gateway.h"                   // The main node is the Gateway, we have just one node
#include "conf/Webhook.h"                   // Enable DHCP and DNS

// Include framework code and libraries
#include <SPI.h>
#include <DHT.h>

/*** All configuration includes should be above this line ***/
#include "Souliss.h"

uint8_t ip_address[4]  = {192, 168, 1, 17};
uint8_t subnet_mask[4] = {255, 255, 255, 0};
uint8_t ip_gateway[4]  = {192, 168, 1, 1};

#define myvNet_address   0x0011
#define myvNet_subnet    0xFF00
#define myvNet_supern    0x0000
#define DHTTYPE DHT22     // DHT 22 (AM2302), AM2321 

#define SLOT000   0
#define SLOT001   1
#define SLOT002   2
#define SLOT003   3
#define SLOT004   4
#define SLOT005   5
#define SLOT006   6
#define SLOT007   7
#define HUMIDITY              8               // Leave 2 slots for T58
#define TEMP0                 10               // Leave 2 slots for T52

// --> Attention! revise if needed pull-up or pull-down.
#define PIN_INPUT_022   22
#define PIN_INPUT_024   24
#define PIN_INPUT_026   26
#define PIN_INPUT_028   28
#define PIN_INPUT_030   30
#define PIN_INPUT_032   32
#define PIN_INPUT_034   34
#define PIN_INPUT_036   36
#define PIN_OUTPUT_023   23
#define PIN_OUTPUT_025   25
#define PIN_OUTPUT_027   27
#define PIN_OUTPUT_029   29
#define PIN_OUTPUT_031   31
#define PIN_OUTPUT_033   33
#define PIN_OUTPUT_035   35
#define PIN_OUTPUT_037   37
#define DHTPIN  2         // what digital pin we're connected to

// DHT sensor
DHT dht(DHTPIN, DHTTYPE); // for ESP8266 use dht(DHTPIN, DHTTYPE, 11)

void setup()
{
  Initialize();
  Souliss_SetAddress(myvNet_address, myvNet_subnet, myvNet_supern);
  SetAsGateway(myvNet_address);
  // --> Define here the Remote Node, if any
  //   SetAsPeerNode(myvNet_address, _Numero_del_Nodo_);

  dht.begin();                                // initialize temperature sensor

  Set_SimpleLight(SLOT000);
  Set_SimpleLight(SLOT001);
  Set_SimpleLight(SLOT002);
  Set_SimpleLight(SLOT003);
  Set_SimpleLight(SLOT004);
  Set_SimpleLight(SLOT005);
  Set_SimpleLight(SLOT006);
  Set_SimpleLight(SLOT007);
  Set_Humidity(HUMIDITY);
  Set_Temperature(TEMP0);
  
  pinMode(PIN_INPUT_022, INPUT);
  pinMode(PIN_INPUT_024, INPUT);
  pinMode(PIN_INPUT_026, INPUT);
  pinMode(PIN_INPUT_028, INPUT);
  pinMode(PIN_INPUT_030, INPUT);
  pinMode(PIN_INPUT_032, INPUT);
  pinMode(PIN_INPUT_034, INPUT);
  pinMode(PIN_INPUT_036, INPUT);
  pinMode(PIN_OUTPUT_023, OUTPUT);
  pinMode(PIN_OUTPUT_025, OUTPUT);
  pinMode(PIN_OUTPUT_027, OUTPUT);
  pinMode(PIN_OUTPUT_029, OUTPUT);
  pinMode(PIN_OUTPUT_031, OUTPUT);
  pinMode(PIN_OUTPUT_033, OUTPUT);
  pinMode(PIN_OUTPUT_035, OUTPUT);
  pinMode(PIN_OUTPUT_037, OUTPUT);
}

void loop()
{
  EXECUTEFAST()
  {
    UPDATEFAST();
    FAST_50ms()
    {
      DigIn(PIN_INPUT_022, Souliss_T1n_ToggleCmd, SLOT000);
      Logic_SimpleLight(SLOT000);
      DigOut(PIN_OUTPUT_023, Souliss_T1n_Coil, SLOT000);
    }
    FAST_50ms()
    {
      DigIn(PIN_INPUT_024, Souliss_T1n_ToggleCmd, SLOT001);
      Logic_SimpleLight(SLOT001);
      DigOut(PIN_OUTPUT_025, Souliss_T1n_Coil, SLOT001);
    }
    FAST_50ms()
    {
      DigIn(PIN_INPUT_026, Souliss_T1n_ToggleCmd, SLOT002);
      Logic_SimpleLight(SLOT002);
      DigOut(PIN_OUTPUT_027, Souliss_T1n_Coil, SLOT002);
    }
    FAST_50ms()
    {
      DigIn(PIN_INPUT_028, Souliss_T1n_ToggleCmd, SLOT003);
      Logic_SimpleLight(SLOT003);
      DigOut(PIN_OUTPUT_029, Souliss_T1n_Coil, SLOT003);
    }
    FAST_50ms()
    {
      DigIn(PIN_INPUT_030, Souliss_T1n_ToggleCmd, SLOT004);
      Logic_SimpleLight(SLOT004);
      DigOut(PIN_OUTPUT_031, Souliss_T1n_Coil, SLOT004);
    }
    FAST_50ms()
    {
      DigIn(PIN_INPUT_032, Souliss_T1n_ToggleCmd, SLOT005);
      Logic_SimpleLight(SLOT005);
      DigOut(PIN_OUTPUT_033, Souliss_T1n_Coil, SLOT005);
    }
    FAST_50ms()
    {
      DigIn(PIN_INPUT_034, Souliss_T1n_ToggleCmd, SLOT006);
      Logic_SimpleLight(SLOT006);
      DigOut(PIN_OUTPUT_035, Souliss_T1n_Coil, SLOT006);
    }
    FAST_50ms()
    {
      DigIn(PIN_INPUT_036, Souliss_T1n_ToggleCmd, SLOT007);
      Logic_SimpleLight(SLOT007);
      DigOut(PIN_OUTPUT_037, Souliss_T1n_Coil, SLOT007);
    }
    FAST_10ms() {

      // Just process communication as fast as the logics
      ProcessCommunication();
    }

    FAST_GatewayComms();
  }

  EXECUTESLOW()
  {
    UPDATESLOW();
    SLOW_10s()
    {
      Timer_SimpleLight(SLOT000);
    }
    SLOW_10s()
    {
      Timer_SimpleLight(SLOT001);
    }
    SLOW_10s()
    {
      Timer_SimpleLight(SLOT002);
    }
    SLOW_10s()
    {
      Timer_SimpleLight(SLOT003);
    }
    SLOW_10s()
    {
      Timer_SimpleLight(SLOT004);
    }
    SLOW_10s()
    {
      Timer_SimpleLight(SLOT005);
    }
    SLOW_10s()
    {
      Timer_SimpleLight(SLOT006);
    }
    SLOW_10s()
    {
      Timer_SimpleLight(SLOT007);
    }
    SLOW_10s()  {
      float humidity = dht.readHumidity();
      float temperature = dht.readTemperature(false);
      if (!isnan(humidity) || !isnan(temperature)) {
        ImportAnalog(HUMIDITY, &humidity);
        ImportAnalog(TEMP0, &temperature);
      }
    }
  }
}
